import { jsx as _jsx } from "react/jsx-runtime";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { findIconDefinition, library, } from "@fortawesome/fontawesome-svg-core";
import { fas } from "@fortawesome/free-solid-svg-icons";
library.add(fas);
/**
 * This component is a wrapper for the FontAwesomeIcon component.
 * It is used to add icons to any library. More info here: https://fontawesome.com/v5/docs/web/use-with/react
 */
export const NerdIcon = (props) => {
    const { icon, severity, iconColor, size = "3x", onMouseEnter, onMouseLeave, } = props;
    if (!icon) {
        return null;
    }
    return (_jsx("span", { onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave, children: typeof icon === "string" ? (setCustomIconString({ ...{ icon, severity, iconColor, size } })) : (_jsx(FontAwesomeIcon, { icon: icon, size: size, color: iconColor ?? "#0288d1" })) }));
};
/**
 *
 * @param root0
 * @param root0.icon
 * @param root0.iconColor
 * @param root0.severity
 * @param root0.size
 */
function setCustomIconString({ icon, iconColor, severity, size = "3x", }) {
    return (_jsx(FontAwesomeIcon, { icon: setCustomIconDefinition(icon), color: iconColor && iconColor !== ""
            ? iconColor
            : colorSwitch(severity || "info"), size: size }));
}
//TODO: fontawesome-svg-core package needs to be updated. (v5.15.4 current version). The icons name are were changed.
/**
 *
 * @param icon
 */
export function setCustomIconDefinition(icon) {
    const iconLookup = {
        prefix: "fas",
        iconName: icon,
    };
    const customIconDefinition = findIconDefinition(iconLookup);
    return customIconDefinition;
}
/**
 *
 * @param color
 */
export function colorSwitch(color) {
    switch (color) {
        case "error":
            return "#d32f2f";
        case "info":
            return "#0288d1";
        case "success":
            return "#2e7d32";
        case "warning":
            return "#ed6c02";
        default:
            return "#000";
    }
}
//# sourceMappingURL=nerdIcon.js.map